#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-1NKOYzJUhf5EjKxUXsMldk
key:                  servant-0.20.3.0-1NKOYzJUhf5EjKxUXsMldk
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  550a26821713ead6f9090d2c374010fd
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-1NKOYzJUhf5EjKxUXsMldk
depends:
    QuickCheck-2.15.0.1-Gvx9SMBV22v4z5c71KPTnf
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    attoparsec-0.14.4-5JdM0c7xj70IPbvJjnzZkg base-4.18.2.1
    bifunctors-5.6.3-CZzZXvLbxa9LTU6bRNDmAU bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Jy8OxWsCrDaBhFbgZ9qrNJ
    constraints-0.14.3-GmumVSxlGLG7minYpiAY1x containers-0.6.7
    deepseq-1.4.8.1 generics-sop-0.5.1.4-Jm3azQ1bHSLFwLmIcDOhGt
    http-api-data-0.6.1-ECeO0KZU1IgGCYQI58Pc96
    http-media-0.8.1.1-Ib486r2pJvED90mVJ6hppy
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-2ifukYXf4pdA7CoyyYtsZ3
    singleton-bool-0.1.8-2u1Wg3jyUa6ETrxX6UOcVC
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS text-2.0.2
    transformers-0.6.1.0 vault-0.3.1.6-A5QxZPtM2gzJvo6AYwAPI7

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

